@@ -239,6 +239,6 @@ class CPIMB(TransformerMixin, BaseEstimator):
     # Y - Target variable
     def fit_transform(self, data, Y):
         self.fit(data, Y)
-        return self.transform()
+        return self.transform(data)
 
     
